@@ -1,10 +1,10 @@
-from __future__ import print_function
-import Pyro4
+from Pyro5.api import expose, serve
+
 
 something = "Something"
 
 
-@Pyro4.expose
+@expose
 class Thingy(object):
     def __init__(self):
         self.sub = {"name": "value"}
@@ -34,6 +34,6 @@ class Thingy(object):
         return self.sub
 
 
-Pyro4.Daemon.serveSimple({
+serve({
     Thingy: "example.attributes"
-}, ns=False)
+}, use_ns=False)
