@@ -1,10 +1,8 @@
-from __future__ import print_function
-import Pyro4
-
+from Pyro5.api import expose, serve
 from thingy import Thingy
 
 
-@Pyro4.expose
+@expose
 class Factory(object):
     def createSomething(self, number):
         # create a new item
@@ -17,6 +15,6 @@ class Factory(object):
         return thing
 
 
-Pyro4.Daemon.serveSimple({
+serve({
     Factory: "example.autoproxy"
-}, ns=False)
+}, use_ns=False)
