@@ -1,11 +1,11 @@
-from __future__ import print_function
 import time
-import Pyro4
+from Pyro5.api import expose, Daemon
+
 
 print("Autoreconnect using PYRO uri.")
 
 
-@Pyro4.expose
+@expose
 class TestClass(object):
     def method(self, arg):
         print("Method called with %s" % arg)
@@ -22,7 +22,7 @@ class TestClass(object):
 # The other thing is that your Daemon must re-bind on the same port.
 # By default Pyro will select a random port so we specify a fixed port.
 
-with Pyro4.core.Daemon(port=7777) as daemon:
+with Daemon(port=7777) as daemon:
     uri = daemon.register(TestClass, objectId="example.autoreconnect_fixed_objectid")
     print("Server started, uri: %s" % uri)
     daemon.requestLoop()
