@@ -1,12 +1,11 @@
-from __future__ import print_function
 import logging
 import sys
-import Pyro4
+from Pyro5.api import expose, callback, Daemon, Proxy
 
 
 # initialize the logger so you can see what is happening with the callback exception message:
 logging.basicConfig(stream=sys.stderr, format="[%(asctime)s,%(name)s,%(levelname)s] %(message)s")
-log = logging.getLogger("Pyro4")
+log = logging.getLogger("Pyro5")
 log.setLevel(logging.WARNING)
 
 
@@ -16,25 +15,25 @@ class CallbackHandler(object):
         b = 0
         return a // b
 
-    @Pyro4.expose
+    @expose
     def call1(self):
         print("\n\ncallback 1 received from server!")
         print("going to crash - you won't see the exception here, only on the server")
         return self.crash()
 
-    @Pyro4.expose
-    @Pyro4.callback
+    @expose
+    @callback
     def call2(self):
         print("\n\ncallback 2 received from server!")
-        print("going to crash - but you will see the exception here too")
+        print("going to crash - but you will see the exception printed here too:")
         return self.crash()
 
 
-daemon = Pyro4.core.Daemon()
+daemon = Daemon()
 callback = CallbackHandler()
 daemon.register(callback)
 
-with Pyro4.core.Proxy("PYRONAME:example.callback2") as server:
+with Proxy("PYRONAME:example.callback2") as server:
     server.doCallback(callback)   # this is a oneway call, so we can continue right away
 
 print("waiting for callbacks to arrive...")
