@@ -1,25 +1,27 @@
-import Pyro4
+from Pyro5.api import expose, oneway, serve
+import Pyro5.errors
 
 
 class CallbackServer(object):
-    @Pyro4.expose
-    @Pyro4.oneway
+    @expose
+    @oneway
     def doCallback(self, callback):
         print("\n\nserver: doing callback 1 to client")
+        callback._pyroClaimOwnership()
         try:
             callback.call1()
-        except:
+        except Exception:
             print("got an exception from the callback:")
-            print("".join(Pyro4.util.getPyroTraceback()))
+            print("".join(Pyro5.errors.get_pyro_traceback()))
         print("\n\nserver: doing callback 2 to client")
         try:
             callback.call2()
-        except:
+        except Exception:
             print("got an exception from the callback:")
-            print("".join(Pyro4.util.getPyroTraceback()))
+            print("".join(Pyro5.errors.get_pyro_traceback()))
         print("server: callbacks done.\n")
 
 
-Pyro4.Daemon.serveSimple({
+serve({
     CallbackServer: "example.callback2"
 })
