@@ -1,12 +1,11 @@
-from __future__ import print_function
-import Pyro4
+import Pyro5.api
 import threading
 
 
-@Pyro4.expose
+@Pyro5.api.expose
 class EchoServer(object):
     def echo(self, message):
-        ctx = Pyro4.current_context
+        ctx = Pyro5.api.current_context
         print("\nGot Message:", message)
         print("  thread: ", threading.current_thread().ident)
         print("  obj.pyroid: ", self._pyroId)
@@ -18,21 +17,20 @@ class EchoServer(object):
         print("  context.serializer_id: ", ctx.serializer_id)
         print("  context.correlation_id:", ctx.correlation_id)
         if "XYZZ" in ctx.annotations:
-            print("  custom annotation 'XYZZ':", ctx.annotations["XYZZ"])
+            print("  custom annotation 'XYZZ':", bytes(ctx.annotations["XYZZ"]))
         return message
 
-    @Pyro4.oneway
+    @Pyro5.api.oneway
     def oneway(self, message):
         return self.echo(message)
 
 
-class CustomDaemon(Pyro4.Daemon):
+class CustomDaemon(Pyro5.api.Daemon):
     def annotations(self):
         return {"DDAA": b"custom response annotation set by the daemon"}
 
 
 with CustomDaemon() as daemon:
-    daemon._pyroHmacKey = b"secr3t_k3y"
     uri = daemon.register(EchoServer, "example.context")  # provide a logical name ourselves
     print("Server is ready. You can use the following URI to connect:")
     print(uri)
