@@ -1,17 +1,16 @@
-from __future__ import print_function
-import Pyro4.core
-import Pyro4.naming
+import Pyro5.api
 import chain
 
+
 this_node = "B"
 next_node = "C"
 
 servername = "example.chain." + this_node
 
-with Pyro4.core.Daemon() as daemon:
+with Pyro5.api.Daemon() as daemon:
     obj = chain.Chain(this_node, next_node)
     uri = daemon.register(obj)
-    with Pyro4.naming.locateNS() as ns:
+    with Pyro5.api.locate_ns() as ns:
         ns.register(servername, uri)
 
     # enter the service loop.
