@@ -1,12 +1,10 @@
 import random
-import sys
-import Pyro4
-from Pyro4.util import SerializerBase
+from Pyro5.api import Proxy, register_dict_to_class
 from workitem import Workitem
 
 
 # For 'workitem.Workitem' we register a deserialization hook to be able to get these back from Pyro
-SerializerBase.register_dict_to_class("workitem.Workitem", Workitem.from_dict)
+register_dict_to_class("workitem.Workitem", Workitem.from_dict)
 
 NUMBER_OF_ITEMS = 40
 
@@ -15,7 +13,7 @@ def main():
     print("\nThis program will calculate Prime Factorials of a bunch of random numbers.")
     print("The more workers you will start (on different cpus/cores/machines),")
     print("the faster you will get the complete list of results!\n")
-    with Pyro4.core.Proxy("PYRONAME:example.distributed.dispatcher") as dispatcher:
+    with Proxy("PYRONAME:example.distributed.dispatcher") as dispatcher:
         placework(dispatcher)
         numbers = collectresults(dispatcher)
     printresults(numbers)
@@ -24,12 +22,7 @@ def main():
 def placework(dispatcher):
     print("placing work items into dispatcher queue.")
     for i in range(NUMBER_OF_ITEMS):
-        if sys.version_info < (3, 0):
-            # python 2.x range arguments needs to be within C int range
-            number = random.randint(3211, 12000) * random.randint(3211, 11000)
-        else:
-            # python 3.x allows arbitrary size range
-            number = random.randint(3211, 4999999) * random.randint(3211, 999999)
+        number = random.randint(3211, 4999999) * random.randint(3211, 999999)
         item = Workitem(i + 1, number)
         dispatcher.putWork(item)
 
