@@ -1,20 +1,14 @@
-from __future__ import print_function
-
-try:
-    import queue
-except ImportError:
-    import Queue as queue
-import Pyro4
-from Pyro4.util import SerializerBase
+import queue
+from Pyro5.api import expose, behavior, serve, register_dict_to_class
 from workitem import Workitem
 
 
 # For 'workitem.Workitem' we register a deserialization hook to be able to get these back from Pyro
-SerializerBase.register_dict_to_class("workitem.Workitem", Workitem.from_dict)
+register_dict_to_class("workitem.Workitem", Workitem.from_dict)
 
 
-@Pyro4.expose
-@Pyro4.behavior(instance_mode="single")
+@expose
+@behavior(instance_mode="single")
 class DispatcherQueue(object):
     def __init__(self):
         self.workqueue = queue.Queue()
@@ -44,8 +38,9 @@ class DispatcherQueue(object):
     def resultQueueSize(self):
         return self.resultqueue.qsize()
 
+
 # main program
 
-Pyro4.Daemon.serveSimple({
+serve({
     DispatcherQueue: "example.distributed.dispatcher"
 })
