@@ -1,6 +1,6 @@
 #!/usr/bin/env bash
 
-python -m Pyro4.naming &
+python -m Pyro5.nameserver &
 sleep 0.5
 
 NUM_CPUS=$(python -c "import os; print(os.cpu_count())")
