@@ -1,9 +1,8 @@
-from __future__ import print_function, division
+from Pyro5.api import expose, Daemon, locate_ns
 import sys
-import Pyro4
 
 
-@Pyro4.expose
+@expose
 class Mandelbrot(object):
     maxiters = 500
 
@@ -36,9 +35,10 @@ class Mandelbrot(object):
         return self.maxiters
 
 
-@Pyro4.expose
+@expose
 class MandelbrotColorPixels(object):
     maxiters = 500
+
     def calc_photoimage_line(self, y, res_x, res_y):
         line = []
         for x in range(res_x):
@@ -73,8 +73,8 @@ if __name__ == "__main__":
         raise SystemExit("give argument: server_id number")
 
     server_id = int(sys.argv[1])
-    with Pyro4.Daemon() as d:
-        with Pyro4.locateNS() as ns:
+    with Daemon() as d:
+        with locate_ns() as ns:
             mandel_server = d.register(Mandelbrot)
             mandel_color_server = d.register(MandelbrotColorPixels)
             ns.register("mandelbrot_"+str(server_id), mandel_server, safe=True, metadata={"class:mandelbrot_calc"})
