@@ -1,19 +1,12 @@
-from __future__ import print_function
-import sys
-
-import Pyro4
-import Pyro4.util
+from Pyro5.api import Proxy
+import Pyro5.errors
 
 
 print("First start the built-in test echo server with something like:")
-print("$ python -m Pyro4.test.echoserver")
+print("$ python -m Pyro5.utils.echoserver")
 print("Enter the server's uri that was printed:")
-if sys.version_info < (3, 0):
-    uri = raw_input()
-else:
-    uri = input()
-uri = uri.strip()
-echoserver = Pyro4.Proxy(uri)
+uri = input().strip()
+echoserver = Proxy(uri)
 
 response = echoserver.echo("hello")
 print("\ngot back from the server: %s" % response)
@@ -25,9 +18,9 @@ for element in echoserver.generator():
 
 try:
     echoserver.error()
-except:
+except Exception:
     print("\ncaught an exception (expected), traceback:")
-    print("".join(Pyro4.util.getPyroTraceback()))
+    print("".join(Pyro5.errors.get_pyro_traceback()))
 
 print("\nshutting down the test echo server. (restart it if you want to run this again)")
 echoserver.shutdown()
