@@ -1,13 +1,7 @@
-from __future__ import print_function
-import sys
-
-import Pyro4
+from Pyro5.api import Proxy
 
 
-if sys.version_info < (3, 0):
-    input = raw_input
-
-with Pyro4.core.Proxy("PYRONAME:example.embedded.server") as proxy:
+with Proxy("PYRONAME:example.eventloop.server") as proxy:
     print("5*11=%d" % proxy.multiply(5, 11))
     print("'x'*10=%s" % proxy.multiply('x', 10))
 
