@@ -14,18 +14,10 @@ thread has put something in it.
 """
 import time
 import threading
-try:
-    import queue
-except ImportError:
-    import Queue as queue
-import Pyro4
-
-try:
-    from tkinter import *
-    import tkinter.simpledialog as simpledialog
-except ImportError:
-    from Tkinter import *
-    import tkSimpleDialog as simpledialog
+import queue
+from tkinter import *
+import tkinter.simpledialog as simpledialog
+from Pyro5.api import expose, Daemon
 
 
 # The frequency with which the GUI mainloop checks for work in the Pyro queue.
@@ -55,7 +47,7 @@ class PyroGUI(object):
         buttonframe.pack(fill=X)
         rlabel = Label(frame, text="Pyro server messages:")
         rlabel.pack(fill=X)
-        self.msg = Message(frame, anchor=NW, width=500, aspect=80, background="white", relief="sunken")
+        self.msg = Message(frame, anchor=NW, width=500, aspect=80, background="white", fg="black", relief="sunken")
         self.msg.pack(fill=BOTH, expand=1)
         frame.pack(fill=BOTH)
         self.serveroutput = []
@@ -101,7 +93,7 @@ class PyroGUI(object):
         self.msg.config(text="\n".join(self.serveroutput))
 
 
-@Pyro4.expose
+@expose
 class MessagePrinter(object):
     """
     The Pyro object that interfaces with the GUI application.
@@ -139,14 +131,14 @@ class MessagePrinter(object):
         })
 
 
-class PyroDaemon(threading.Thread):
+class MyPyroDaemon(threading.Thread):
     def __init__(self, gui):
         threading.Thread.__init__(self)
         self.gui = gui
         self.started = threading.Event()
 
     def run(self):
-        daemon = Pyro4.Daemon()
+        daemon = Daemon()
         obj = MessagePrinter(self.gui)
         self.uri = daemon.register(obj, "pyrogui.message2")
         self.started.set()
@@ -157,8 +149,8 @@ def main():
     gui = PyroGUI()
 
     # create a pyro daemon with object, running in its own worker thread
-    pyro_thread = PyroDaemon(gui)
-    pyro_thread.setDaemon(True)
+    pyro_thread = MyPyroDaemon(gui)
+    pyro_thread.daemon = True
     pyro_thread.start()
     pyro_thread.started.wait()
 
