@@ -1,12 +1,7 @@
-from __future__ import print_function
-import sys
-import Pyro4
-
-if sys.version_info < (3, 0):
-    input = raw_input
+from Pyro5.api import Proxy
 
 
-class CustomHandshakeProxy(Pyro4.Proxy):
+class CustomHandshakeProxy(Proxy):
     def _pyroValidateHandshake(self, response):
         # this will get called if the connection is okay by the server
         print("Proxy received handshake response data: ", response)
