@@ -1,31 +1,36 @@
-from __future__ import print_function
-import Pyro4
+from Pyro5.api import expose, behavior, serve, current_context
 
 
-@Pyro4.behavior(instance_mode="single")
+@behavior(instance_mode="single")
 class SingleInstance(object):
-    @Pyro4.expose
+    def __init__(self):
+        print("created SingleInstance instance with id", id(self))
+    @expose
     def msg(self, message):
         print("[%s] %s.msg: %s" % (id(self), self.__class__.__name__, message))
         return id(self)
 
 
-@Pyro4.behavior(instance_mode="session", instance_creator=lambda clazz: clazz.create_instance())
+@behavior(instance_mode="session", instance_creator=lambda clazz: clazz.create_instance())
 class SessionInstance(object):
-    @Pyro4.expose
+    def __init__(self):
+        print("created SessionInstance instance with id", id(self))
+    @expose
     def msg(self, message):
         print("[%s] %s.msg: %s" % (id(self), self.__class__.__name__, message))
         return id(self), self.correlation_id
     @classmethod
     def create_instance(cls):
         obj = cls()
-        obj.correlation_id = Pyro4.current_context.correlation_id
+        obj.correlation_id = current_context.correlation_id
         return obj
 
 
-@Pyro4.behavior(instance_mode="percall")
+@behavior(instance_mode="percall")
 class PercallInstance(object):
-    @Pyro4.expose
+    def __init__(self):
+        print("created PercallInstance instance with id", id(self))
+    @expose
     def msg(self, message):
         print("[%s] %s.msg: %s" % (id(self), self.__class__.__name__, message))
         return id(self)
@@ -33,7 +38,7 @@ class PercallInstance(object):
 
 if __name__ == "__main__":
     # please make sure a name server is running somewhere first.
-    Pyro4.Daemon.serveSimple({
+    serve({
         SingleInstance: "instance.single",
         SessionInstance: "instance.session",
         PercallInstance: "instance.percall"
