@@ -2,18 +2,15 @@
 This is the subscriber for the 'many topics' messages example.
 For code with more explanations, see the regular 'weather' message example code.
 """
-from __future__ import print_function
 import os
 import time
 import threading
-import Pyro4
 from operator import itemgetter
+from Pyro5.api import expose, Daemon
 from messagebus.messagebus import Subscriber
 
-Pyro4.config.AUTOPROXY = True
 
-
-@Pyro4.expose
+@expose
 class Subber(Subscriber):
     def init_counters(self, topics):
         self.message_counter = {}
@@ -32,7 +29,7 @@ def clear_screen():
 
 
 subber = Subber()
-d = Pyro4.Daemon()
+d = Daemon()
 d.register(subber)
 daemon_thread = threading.Thread(target=d.requestLoop)
 daemon_thread.daemon = True
