@@ -1,10 +1,9 @@
 """
 Pyro MessageBus:  a simple pub/sub message bus.
-Provides a way of communicating where the sender and receivers are fully decoupled.
+Provides a way of cummunicating where the sender and receivers are fully decoupled.
 
 Pyro - Python Remote Objects.  Copyright by Irmen de Jong (irmen@razorvine.net).
 """
-from __future__ import print_function
 import threading
 import uuid
 import datetime
@@ -12,32 +11,20 @@ import time
 import logging
 import traceback
 import sys
+import pickle
+import contextlib
 from collections import defaultdict
 from contextlib import closing
-try:
-    import cPickle as pickle
-except ImportError:
-    import pickle
-try:
-    import sqlite3
-except ImportError:
-    sqlite3 = None
-try:
-    import queue
-except ImportError:
-    import Queue as queue
-import Pyro4
-import Pyro4.errors
-from Pyro4.util import SerializerBase
+import sqlite3
+import queue
+from Pyro5.api import expose, behavior, oneway, Proxy, register_class_to_dict, register_dict_to_class
+import Pyro5.errors
 from . import PYRO_MSGBUS_NAME
 
 
-__all__ = ["MessageBus", "Message", "SerializerBase"]
+__all__ = ["MessageBus", "Message"]
 
-log = logging.getLogger("Pyro4.MessageBus")
-
-if sys.version_info >= (3, 0):
-    basestring = str
+log = logging.getLogger("Pyro5.MessageBus")
 
 
 class Message(object):
@@ -51,7 +38,7 @@ class Message(object):
     @staticmethod
     def to_dict(obj):
         return {
-            "__class__": "Pyro4.utils.messagebus.message",
+            "__class__": "Pyro5.utils.messagebus.message",
             "msgid": str(obj.msgid),
             "created": obj.created.isoformat(),
             "data": obj.data
@@ -63,15 +50,16 @@ class Message(object):
                    datetime.datetime.strptime(d["created"], "%Y-%m-%dT%H:%M:%S.%f"),
                    d["data"])
 
+
 # make sure Pyro knows how to serialize the custom Message class
-SerializerBase.register_class_to_dict(Message, Message.to_dict)
-SerializerBase.register_dict_to_class("Pyro4.utils.messagebus.message", Message.from_dict)
+register_class_to_dict(Message, Message.to_dict)
+register_dict_to_class("Pyro5.utils.messagebus.message", Message.from_dict)
 
 
-@Pyro4.expose
+@expose
 class Subscriber(object):
     def __init__(self, auto_consume=True, max_queue_size=5000):
-        self.bus = Pyro4.Proxy("PYRONAME:"+PYRO_MSGBUS_NAME)
+        self.bus = Proxy("PYRONAME:"+PYRO_MSGBUS_NAME)
         self.received_messages = queue.Queue(maxsize=max_queue_size)
         if auto_consume:
             self.__bus_consumer_thread = threading.Thread(target=self.__bus_consume_message)
@@ -133,12 +121,10 @@ class MemoryStorage(object):
             if hasattr(sub, "_pyroRelease"):
                 sub._pyroRelease()
             if hasattr(sub, "_pyroUri"):
-                try:
+                with contextlib.suppress(KeyError):
                     proxy = self.proxy_cache[sub._pyroUri]
                     proxy._pyroRelease()
                     del self.proxy_cache[sub._pyroUri]
-                except KeyError:
-                    pass
         del self.subscribers[topic]
 
     def add_message(self, topic, message):
@@ -157,12 +143,10 @@ class MemoryStorage(object):
             if hasattr(subscriber, "_pyroRelease"):
                 subscriber._pyroRelease()
             if hasattr(subscriber, "_pyroUri"):
-                try:
+                with contextlib.suppress(KeyError):
                     proxy = self.proxy_cache[subscriber._pyroUri]
                     proxy._pyroRelease()
                     del self.proxy_cache[subscriber._pyroUri]
-                except KeyError:
-                    pass
             self.subscribers[topic].discard(subscriber)
 
     def all_pending_messages(self):
@@ -185,10 +169,8 @@ class MemoryStorage(object):
             if topic in self.messages:
                 msg_list = self.messages[topic]
                 for message in topics_messages[topic]:
-                    try:
+                    with contextlib.suppress(ValueError):
                         msg_list.remove(message)
-                    except ValueError:
-                        pass
 
     def stats(self):
         subscribers = pending = 0
@@ -271,19 +253,13 @@ CREATE TABLE IF NOT EXISTS Subscription(
             cursor.execute("DELETE FROM Topic WHERE id=?", [topic_id])
         conn.commit()
         for uri in sub_uris:
-            try:
+            with contextlib.suppress(KeyError):
                 proxy = self.proxy_cache[uri]
                 proxy._pyroRelease()
                 del self.proxy_cache[uri]
-            except KeyError:
-                pass
 
     def add_message(self, topic, message):
         msg_data = pickle.dumps(message.data, pickle.HIGHEST_PROTOCOL)
-        if sys.version_info < (3, 0):
-            blob_data = buffer(msg_data)
-        else:
-            blob_data = msg_data
         conn = self.dbconn()
         conn.execute("PRAGMA foreign_keys=ON")
         with closing(conn.cursor()) as cursor:
@@ -294,14 +270,14 @@ CREATE TABLE IF NOT EXISTS Subscription(
             if cursor.execute("SELECT EXISTS(SELECT 1 FROM Subscription WHERE topic=?)", [topic_id]).fetchone()[0]:
                 # there is at least one subscriber for this topic, insert the message (otherwise just discard it)
                 cursor.execute("INSERT INTO Message(id, created, topic, msgdata) VALUES (?,?,?,?)",
-                               [str(message.msgid), message.created, topic_id, blob_data])
+                               [str(message.msgid), message.created, topic_id, msg_data])
         conn.commit()
         self.total_msg_count += 1
 
     def add_subscriber(self, topic, subscriber):
         if not hasattr(subscriber, "_pyroUri"):
             raise ValueError("can only store subscribers that are a Pyro proxy")
-        uri = subscriber._pyroUri.asString()
+        uri = str(subscriber._pyroUri)
         conn = self.dbconn()
         conn.execute("PRAGMA foreign_keys=ON")
         with closing(conn.cursor()) as cursor:
@@ -314,16 +290,14 @@ CREATE TABLE IF NOT EXISTS Subscription(
     def remove_subscriber(self, topic, subscriber):
         conn = self.dbconn()
         conn.execute("PRAGMA foreign_keys=ON")
-        uri = subscriber._pyroUri.asString()
+        uri = str(subscriber._pyroUri)
         with closing(conn.cursor()) as cursor:
             cursor.execute("DELETE FROM Subscription WHERE topic=(SELECT id FROM Topic WHERE topic=?) AND subscriber=?", [topic, uri])
         conn.commit()
-        try:
+        with contextlib.suppress(KeyError):
             proxy = self.proxy_cache[uri]
-            proxy._pyroRelease()
+            proxy._pyroClaimOwnership()   # because it has been used from a different thread. This also kills any connection.
             del self.proxy_cache[uri]
-        except KeyError:
-            pass
 
     def all_pending_messages(self):
         conn = self.dbconn()
@@ -331,10 +305,7 @@ CREATE TABLE IF NOT EXISTS Subscription(
             msgs = cursor.execute("SELECT t.topic, m.id, m.created, m.msgdata FROM Message AS m, Topic as t WHERE m.topic=t.id").fetchall()
         result = defaultdict(list)
         for msg in msgs:
-            if sys.version_info < (3, 0):
-                blob_data = str(msg[3])
-            else:
-                blob_data = msg[3]
+            blob_data = msg[3]
             result[msg[0]].append(Message(uuid.UUID(msg[1]), datetime.datetime.strptime(msg[2], "%Y-%m-%d %H:%M:%S.%f"), pickle.loads(blob_data)))
         return result
 
@@ -359,7 +330,7 @@ CREATE TABLE IF NOT EXISTS Subscription(
                     subs[topic].append(proxy)
                 else:
                     try:
-                        proxy = Pyro4.Proxy(uri)
+                        proxy = Proxy(uri)
                     except Exception:
                         log.exception("Cannot create pyro proxy, sub_id=%d, uri=%s", sub_id, uri)
                         cursor.execute("DELETE FROM Subscription WHERE id=?", [sub_id])
@@ -397,8 +368,8 @@ def make_messagebus(clazz):
         raise ValueError("invalid storagetype")
 
 
-@Pyro4.behavior(instance_mode="single", instance_creator=make_messagebus)
-@Pyro4.expose
+@behavior(instance_mode="single", instance_creator=make_messagebus)
+@expose
 class MessageBus(object):
     def __init__(self, storage=None):
         if storage is None:
@@ -413,7 +384,7 @@ class MessageBus(object):
         log.info("started")
 
     def add_topic(self, topic):
-        if not isinstance(topic, basestring):
+        if not isinstance(topic, str):
             raise TypeError("topic must be str")
         with self.msg_lock:
             self.storage.create_topic(topic)
@@ -439,7 +410,7 @@ class MessageBus(object):
         self.msg_added.set()   # signal that a new message has arrived
         self.msg_added.clear()
 
-    @Pyro4.oneway
+    @oneway
     def send_no_ack(self, topic, message):
         self.send(topic, message)
 
@@ -488,10 +459,11 @@ class MessageBus(object):
                         # skipping because subscriber is scheduled for removal
                         continue
                     try:
+                        subscriber._pyroClaimOwnership()   # because we run in a different thread now
                         try:
                             # send the batch of messages pending for this topic in one go
                             subscriber.incoming_messages(topic, messages)
-                        except Pyro4.errors.MessageTooLargeError:
+                        except Pyro5.errors.MessageTooLargeError:
                             # the batch doesn't fit in the configured max msg size, send them one by one instead
                             for message in messages:
                                 subscriber.incoming_message(topic, message)
