@@ -1,4 +1,4 @@
-from Pyro4 import expose
+from Pyro5.server import expose
 
 
 class Resource(object):
