@@ -1,16 +1,16 @@
-from __future__ import print_function
 import time
-import Pyro4
+from Pyro5.api import Proxy
 
 
-with Pyro4.core.Proxy("PYRONAME:example.oneway") as serv:
+with Proxy("PYRONAME:example.oneway") as serv:
     print("starting server using a oneway call")
     serv.oneway_start(6)
-    print("doing some more oneway calls inbetween")
+    print("doing some more oneway calls inbetween (this should be finished really quick)")
     serv.nothing()
     serv.nothing()
     serv.nothing()
     serv.nothing()
+    print("oneway calls done, this should have taken almost no time.")
 
     time.sleep(2)
     print("\nNow contacting the server to see if it's done.")
@@ -26,5 +26,6 @@ with Pyro4.core.Proxy("PYRONAME:example.oneway") as serv:
             time.sleep(1)
 
     print("getting the result from the server: %s" % serv.result())
-    print("\nCalling oneway work method, server will continue working while we are done (check the server console output).")
+    print("\nCalling oneway work method, server will continue working while we are done "
+          "(quickly check the server console output now to see it running!).")
     serv.oneway_work()
