@@ -1,20 +1,13 @@
-from __future__ import print_function
 import time
-
-import Pyro4
+from Pyro5.api import expose, oneway, serve
 
 
-# set the oneway behavior to run inside a new thread, otherwise the client stalls.
-# this is the default, but I've added it here just for clarification.
-Pyro4.config.ONEWAY_THREADED = True
-
-
-@Pyro4.expose
+@expose
 class Server(object):
     def __init__(self):
         self.busy = False
 
-    @Pyro4.oneway
+    @oneway
     def oneway_start(self, duration):
         print("start request received. Starting work...")
         self.busy = True
@@ -34,7 +27,7 @@ class Server(object):
     def nothing(self):
         print("nothing got called, doing nothing")
 
-    @Pyro4.oneway
+    @oneway
     def oneway_work(self):
         for i in range(10):
             print("work work..", i+1)
@@ -42,8 +35,6 @@ class Server(object):
         print("work's done!")
 
 
-# main program
-
-Pyro4.Daemon.serveSimple({
+serve({
     Server: "example.oneway"
 })
