@@ -1,16 +1,10 @@
-from __future__ import print_function
-import sys
 import random
-import Pyro4
-
-
-if sys.version_info < (3, 0):
-    input = raw_input
+from Pyro5.api import Proxy
 
 
 uri = input("Enter the URI of the server object: ")
 
-with Pyro4.Proxy(uri) as proxy:
+with Proxy(uri) as proxy:
     print("currently allocated resources:", proxy.list())
     name1 = hex(random.randint(0, 999999))[-4:]
     name2 = hex(random.randint(0, 999999))[-4:]
