@@ -1,10 +1,9 @@
-from __future__ import print_function
 import random
-
-import Pyro4
+from Pyro5.api import Proxy
+import Pyro5.errors
 
 
-shop = Pyro4.Proxy("PYRONAME:example.shop")
+shop = Proxy("PYRONAME:example.shop")
 
 print("Simulating some customers.")
 harrysCart = shop.enter("Harry")
@@ -38,8 +37,8 @@ print("Customers currently in the shop: %s" % shop.customers())
 
 try:
     receipt = shop.payByName("Harry")
-except:
-    print("ERROR: %s" % ("".join(Pyro4.util.getPyroTraceback())))
+except Exception:
+    print("ERROR: %s" % ("".join(Pyro5.errors.get_pyro_traceback())))
 print("Harry payed. The cart now contains: %s (should be empty)" % harrysCart.getContents())
 print("Harry got this receipt:")
 print(receipt)
@@ -54,8 +53,8 @@ shop.leave("Sally")
 print("Shoplifter is leaving. (should be impossible i.e. give an error)")
 try:
     shop.leave("shoplifter")
-except:
-    print("".join(Pyro4.util.getPyroTraceback()))
+except Exception:
+    print("".join(Pyro5.errors.get_pyro_traceback()))
 
 print("Harry is attempting to put stuff back in his cart again,")
 print("which should fail because the cart does no longer exist.")
