@@ -1,18 +1,17 @@
 # this only works on Linux
 # it uses the abstract namespace socket feature.
 
-from __future__ import print_function
-import Pyro4
+from Pyro5.api import expose, Daemon
 
 
-@Pyro4.expose
+@expose
 class Thingy(object):
     def message(self, arg):
         print("Message received:", arg)
         return "Roger!"
 
 
-with Pyro4.Daemon(unixsocket="\0example_unix.sock") as d:   # notice the 0-byte at the start
+with Daemon(unixsocket="\0example_unix.sock") as d:   # notice the 0-byte at the start
     uri = d.register(Thingy, "example.unixsock")
     print("Server running, uri=", uri)
     string_uri = str(uri)
