@@ -1,35 +1,29 @@
-from __future__ import print_function
 import threading
 import time
 import sys
-import Pyro4
+import Pyro5.errors
+import Pyro5.api
 
-
-if sys.version_info < (3, 0):
-    input = raw_input
+sys.excepthook = Pyro5.errors.excepthook
 
 
 def get_user_token():
     return "user123"
 
 
-class CustomAnnotationProxy(Pyro4.Proxy):
-    # override the method that adds annotations and add our own custom user token annotation
-    def _pyroAnnotations(self):
-        return {"USER": get_user_token().encode("utf-8")}
-
-
 class DbAccessor(threading.Thread):
     def __init__(self, uri):
         super(DbAccessor, self).__init__()
-        self.proxy = CustomAnnotationProxy(uri)
+        self.uri = uri
         self.daemon = True
 
     def run(self):
+        proxy = Pyro5.api.Proxy(self.uri)
         for i in range(3):
             try:
-                self.proxy.store("number", 100+i)
-                num = self.proxy.retrieve("number")
+                Pyro5.api.current_context.annotations = {"USER": get_user_token().encode("utf-8")}
+                proxy.store("number", 100+i)
+                num = proxy.retrieve("number")
                 print("[%s] num=%s" % (self.name, num))
             except Exception:
                 import traceback
@@ -37,16 +31,19 @@ class DbAccessor(threading.Thread):
 
 
 print("\n***** Sequential access using multiple proxies on the Session-Bound Database... (no issues)")
-with CustomAnnotationProxy("PYRONAME:example.usersession.sessiondb") as p1,\
-        CustomAnnotationProxy("PYRONAME:example.usersession.sessiondb") as p2:
+
+with Pyro5.api.Proxy("PYRONAME:example.usersession.sessiondb") as p1, \
+        Pyro5.api.Proxy("PYRONAME:example.usersession.sessiondb") as p2:
+    Pyro5.api.current_context.annotations = {"USER": get_user_token().encode("utf-8")}
     p1.store("number", 42)
     p1.retrieve("number")
     p2.store("number", 43)
     p2.retrieve("number")
 
 print("\n***** Sequential access using multiple proxies on the Singleton Database... (no issues)")
-with CustomAnnotationProxy("PYRONAME:example.usersession.singletondb") as p1,\
-        CustomAnnotationProxy("PYRONAME:example.usersession.singletondb") as p2:
+with Pyro5.api.Proxy("PYRONAME:example.usersession.singletondb") as p1, \
+        Pyro5.api.Proxy("PYRONAME:example.usersession.singletondb") as p2:
+    Pyro5.api.current_context.annotations = {"USER": get_user_token().encode("utf-8")}
     p1.store("number", 42)
     p1.retrieve("number")
     p2.store("number", 43)
@@ -62,7 +59,7 @@ time.sleep(1)
 t1.join()
 t2.join()
 
-print("\n***** Multiple concurrent proxies on the Singleton Database... (threading problem)")
+print("\n***** Multiple concurrent proxies on the Singleton Database... (concurrency errors will occur!)")
 input("enter to start: ")
 t1 = DbAccessor("PYRONAME:example.usersession.singletondb")
 t2 = DbAccessor("PYRONAME:example.usersession.singletondb")
