@@ -1,14 +1,13 @@
 # This is the code that visits the warehouse.
 import sys
-
-import Pyro4
-import Pyro4.util
+import Pyro5.errors
+from Pyro5.api import Proxy
 from person import Person
 
 
-sys.excepthook = Pyro4.util.excepthook
+sys.excepthook = Pyro5.errors.excepthook
 
-warehouse = Pyro4.Proxy("PYRONAME:example.warehouse")
+warehouse = Proxy("PYRONAME:example.warehouse")
 janet = Person("Janet")
 henry = Person("Henry")
 janet.visit(warehouse)
